export declare abstract class GradientType {
    gradient?: string;
    abstract valueToHex(value: number, range: number): number;
    abstract range(): [number, number] | null;
}
export declare function normalizeValue(lo: number, hi: number, val: number): {
    lo: number;
    hi: number;
    val: number;
};
export declare function getGradient(grad: any): any;
/**
 * Color scheme red to white to blue, for charges
 * Reverse gradients are supported when min>max so that the colors are displayed in reverse order.
 */
export declare class RWB extends GradientType {
    gradient: string;
    min: number;
    max: number;
    mid?: number;
    mult: number;
    constructor(min: number | [number, number], max?: number, mid?: number);
    range(): [number, number];
    valueToHex(val: any, range: any): any;
}
/**
 * rainbow gradient, but without purple to match jmol
 * Reverse gradients are supported when min>max so that the colors are displayed in reverse order.
 */
export declare class ROYGB extends GradientType {
    gradient: string;
    mult: number;
    max: number;
    min: number;
    constructor(min: any, max: any);
    valueToHex(val: any, range: any): any;
    range(): [number, number];
}
/**
 * @constructor Sinebow
 * rainbow gradient with constant saturation, all the way to purple!
 * Reverse gradients are supported when min>max so that the colors are displayed in reverse order.
 *
 * @example $.get('data/1fas.pqr', function(data){
      viewer.addModel(data, "pqr");
      $.get("data/1fas.cube",function(volumedata){
          viewer.addSurface($3Dmol.SurfaceType.VDW, {
              opacity:0.85,
              voldata: new $3Dmol.VolumeData(volumedata, "cube"),
              volscheme: new $3Dmol.Gradient.Sinebow(2,0,1)
          },{});
          
      viewer.render();
      });
      viewer.zoomTo();
  });
 */
export declare class Sinebow extends GradientType {
    gradient: string;
    mult: number;
    max: number;
    min: number;
    constructor(min: any, max: any);
    valueToHex(val: any, range: any): number;
    range(): [number, number];
}
export declare const builtinGradients: {
    rwb: typeof RWB;
    RWB: typeof RWB;
    roygb: typeof ROYGB;
    ROYGB: typeof ROYGB;
    sinebow: typeof Sinebow;
};
export declare class Gradient extends GradientType {
    static RWB: typeof RWB;
    static ROYGB: typeof ROYGB;
    static Sinebow: typeof Sinebow;
    static builtinGradients: {
        rwb: typeof RWB;
        RWB: typeof RWB;
        roygb: typeof ROYGB;
        ROYGB: typeof ROYGB;
        sinebow: typeof Sinebow;
    };
    static normalizeValue: typeof normalizeValue;
    static getGradient: typeof getGradient;
    valueToHex(_value: number, _range: number): number;
    range(): [number, number];
}
