import type { Material } from './../materials/Material';
import { EventDispatcher } from "./EventDispatcher";
import { Vector3 } from "../math";
import { Color } from "./Color";
export declare class GeometryGroup {
    id: number;
    vertexArray: Float32Array | null;
    colorArray: Float32Array | null;
    normalArray: Float32Array | null;
    radiusArray: Float32Array | null;
    faceArray: Uint16Array | null;
    lineArray: Uint16Array | null;
    vertices: number;
    faceidx: number;
    lineidx: number;
    __inittedArrays: boolean;
    useOffset: unknown;
    constructor(id?: number);
    setColors(setcolor: (r: number, g: number, b: number) => Color | number): void;
    getNumVertices(): number;
    getVertices(): Float32Array;
    getCentroid(): Vector3;
    setNormals(): void;
    /** sets line index array from face arr
    Note - assumes all faces are triangles (i.e. there will
    be an extra diagonal for four-sided faces - user should
    specify linearr for custom shape generation to show wireframe squares
    as rectangles rather than two triangles) */
    setLineIndices(): void;
    vrml(indent: string, material?: Material): string;
    truncateArrayBuffers(mesh?: boolean, reallocatemem?: boolean): void;
}
export declare class Geometry extends EventDispatcher {
    id: number;
    name: string;
    hasTangents: boolean;
    dynamic: boolean;
    radii: boolean;
    mesh: boolean;
    offset: boolean;
    verticesNeedUpdate: boolean;
    elementsNeedUpdate: boolean;
    normalsNeedUpdate: boolean;
    colorsNeedUpdate: boolean;
    buffersNeedUpdate: boolean;
    geometryGroups: GeometryGroup[];
    groups: number;
    constructor(mesh?: boolean, radii?: boolean, offset?: boolean);
    updateGeoGroup(addVertices?: number): GeometryGroup;
    vrml(indent: string, material?: Material): string;
    addGeoGroup(): GeometryGroup;
    setUpNormals(...args: Parameters<GeometryGroup["setNormals"]>): void;
    setColors(...setcolor: Parameters<GeometryGroup["setColors"]>): void;
    setUpWireframe(...lineIndexArgs: Parameters<GeometryGroup["setLineIndices"]>): void;
    initTypedArrays(): void;
    dispose(): void;
    get vertices(): number;
}
export declare let GeometryIDCount: number;
