export declare const htmlColors: {
    aliceblue: number;
    antiquewhite: number;
    aqua: number;
    aquamarine: number;
    azure: number;
    beige: number;
    bisque: number;
    black: number;
    blanchedalmond: number;
    blue: number;
    blueviolet: number;
    brown: number;
    burlywood: number;
    cadetblue: number;
    chartreuse: number;
    chocolate: number;
    coral: number;
    cornflowerblue: number;
    cornsilk: number;
    crimson: number;
    cyan: number;
    darkblue: number;
    darkcyan: number;
    darkgoldenrod: number;
    darkgray: number;
    darkgrey: number;
    darkgreen: number;
    darkkhaki: number;
    darkmagenta: number;
    darkolivegreen: number;
    darkorange: number;
    darkorchid: number;
    darkred: number;
    darksalmon: number;
    darkseagreen: number;
    darkslateblue: number;
    darkslategray: number;
    darkslategrey: number;
    darkturquoise: number;
    darkviolet: number;
    deeppink: number;
    deepskyblue: number;
    dimgray: number;
    dimgrey: number;
    dodgerblue: number;
    firebrick: number;
    floralwhite: number;
    forestgreen: number;
    fuchsia: number;
    gainsboro: number;
    ghostwhite: number;
    gold: number;
    goldenrod: number;
    gray: number;
    grey: number;
    green: number;
    greenyellow: number;
    honeydew: number;
    hotpink: number;
    indianred: number;
    indigo: number;
    ivory: number;
    khaki: number;
    lavender: number;
    lavenderblush: number;
    lawngreen: number;
    lemonchiffon: number;
    lightblue: number;
    lightcoral: number;
    lightcyan: number;
    lightgoldenrodyellow: number;
    lightgray: number;
    lightgrey: number;
    lightgreen: number;
    lightpink: number;
    lightsalmon: number;
    lightseagreen: number;
    lightskyblue: number;
    lightslategray: number;
    lightslategrey: number;
    lightsteelblue: number;
    lightyellow: number;
    lime: number;
    limegreen: number;
    linen: number;
    magenta: number;
    maroon: number;
    mediumaquamarine: number;
    mediumblue: number;
    mediumorchid: number;
    mediumpurple: number;
    mediumseagreen: number;
    mediumslateblue: number;
    mediumspringgreen: number;
    mediumturquoise: number;
    mediumvioletred: number;
    midnightblue: number;
    mintcream: number;
    mistyrose: number;
    moccasin: number;
    navajowhite: number;
    navy: number;
    oldlace: number;
    olive: number;
    olivedrab: number;
    orange: number;
    orangered: number;
    orchid: number;
    palegoldenrod: number;
    palegreen: number;
    paleturquoise: number;
    palevioletred: number;
    papayawhip: number;
    peachpuff: number;
    peru: number;
    pink: number;
    plum: number;
    powderblue: number;
    purple: number;
    rebeccapurple: number;
    red: number;
    rosybrown: number;
    royalblue: number;
    saddlebrown: number;
    salmon: number;
    sandybrown: number;
    seagreen: number;
    seashell: number;
    sienna: number;
    silver: number;
    skyblue: number;
    slateblue: number;
    slategray: number;
    slategrey: number;
    snow: number;
    springgreen: number;
    steelblue: number;
    tan: number;
    teal: number;
    thistle: number;
    tomato: number;
    turquoise: number;
    violet: number;
    wheat: number;
    white: number;
    whitesmoke: number;
    yellow: number;
    yellowgreen: number;
};
export declare type ColorSpec = keyof typeof htmlColors | number;
/**
 * Color representation.
 * @typedef ColorSpec
 * @prop {string} 0xAF10AB - any hex number
 * @prop {string} <html color name>
 */
/**
 
* @typedef ColorschemeSpec
* Built in colorschemes
* @prop {string} <html color>Carbon   - use default element colors but with carbon set to specify html color string
* @prop {string} ssPyMOL - PyMol secondary colorscheme
* @prop {string} ssJmol - Jmol secondary colorscheme
* @prop {string} Jmol - Jmol primary colorscheme
* @prop {string} default - default colorscheme
* @prop {string} amino - amino acid colorscheme
* @prop {string} shapely - shapely protien colorscheme
* @prop {string} nucleic - nucleic acid colorscheme
* @prop {string} chain - standard chain colorscheme
* @prop {string} chainHetatm - chain Hetatm colorscheme
* @prop {string} prop - atomSpec property. Example 'b'. See AtomSpec.
* @prop {Gradient} gradient - Allows the user to provide a gradient to the colorscheme.  Is either a Gradient object or the name of a built-in gradient (rwb, roygb, sinebow)
* @prop {min} - min value for gradient
* @prop {max} - max value for gradient
* @prop {mid} - mid point value for gradient (for rwb)
* @prop {object} map - map of a certain AtomSpec property to a color of the form `{'prop': 'elem', map:elementColors.greenCarbon}` Allows the user to provide a mapping of elements to colors to the colorscheme.  This can be done with any properties, and not just 'elem'.
* @prop {function} colorfunc - Allows the user to provide a function for setting the colorschemes.
*/
/** Preset secondary structure color scheme
 * @struct
 */
export declare const ssColors: {
    pyMol: {
        h: number;
        s: number;
        c: number;
    };
    Jmol: {
        h: number;
        s: number;
        c: number;
    };
};
/** Preset element coloring - from individual element colors to entire mappings (e.g. 'elementColors.Jmol' colors atoms with Jmol stylings)
 * @struct
 */
export declare const elementColors: {
    defaultColor: number;
    /** Jmol-like element colors*/
    Jmol: {
        H: number;
        He: number;
        HE: number;
        Li: number;
        LI: number;
        Be: number;
        BE: number;
        B: number;
        C: number;
        N: number;
        O: number;
        F: number;
        Ne: number;
        NE: number;
        Na: number;
        NA: number;
        Mg: number;
        MG: number;
        Al: number;
        AL: number;
        Si: number;
        SI: number;
        P: number;
        S: number;
        Cl: number;
        CL: number;
        Ar: number;
        AR: number;
        K: number;
        Ca: number;
        CA: number;
        Sc: number;
        SC: number;
        Ti: number;
        TI: number;
        V: number;
        Cr: number;
        CR: number;
        Mn: number;
        MN: number;
        Fe: number;
        FE: number;
        Co: number;
        CO: number;
        Ni: number;
        NI: number;
        Cu: number;
        CU: number;
        Zn: number;
        ZN: number;
        Ga: number;
        GA: number;
        Ge: number;
        GE: number;
        As: number;
        AS: number;
        Se: number;
        SE: number;
        Br: number;
        BR: number;
        Kr: number;
        KR: number;
        Rb: number;
        RB: number;
        Sr: number;
        SR: number;
        Y: number;
        Zr: number;
        ZR: number;
        Nb: number;
        NB: number;
        Mo: number;
        MO: number;
        Tc: number;
        TC: number;
        Ru: number;
        RU: number;
        Rh: number;
        RH: number;
        Pd: number;
        PD: number;
        Ag: number;
        AG: number;
        Cd: number;
        CD: number;
        In: number;
        IN: number;
        Sn: number;
        SN: number;
        Sb: number;
        SB: number;
        Te: number;
        TE: number;
        I: number;
        Xe: number;
        XE: number;
        Cs: number;
        CS: number;
        Ba: number;
        BA: number;
        La: number;
        LA: number;
        Ce: number;
        CE: number;
        Pr: number;
        PR: number;
        Nd: number;
        ND: number;
        Pm: number;
        PM: number;
        Sm: number;
        SM: number;
        Eu: number;
        EU: number;
        Gd: number;
        GD: number;
        Tb: number;
        TB: number;
        Dy: number;
        DY: number;
        Ho: number;
        HO: number;
        Er: number;
        ER: number;
        Tm: number;
        TM: number;
        Yb: number;
        YB: number;
        Lu: number;
        LU: number;
        Hf: number;
        HF: number;
        Ta: number;
        TA: number;
        W: number;
        Re: number;
        RE: number;
        Os: number;
        OS: number;
        Ir: number;
        IR: number;
        Pt: number;
        PT: number;
        Au: number;
        AU: number;
        Hg: number;
        HG: number;
        Tl: number;
        TL: number;
        Pb: number;
        PB: number;
        Bi: number;
        BI: number;
        Po: number;
        PO: number;
        At: number;
        AT: number;
        Rn: number;
        RN: number;
        Fr: number;
        FR: number;
        Ra: number;
        RA: number;
        Ac: number;
        AC: number;
        Th: number;
        TH: number;
        Pa: number;
        PA: number;
        U: number;
        Np: number;
        NP: number;
        Pu: number;
        PU: number;
        Am: number;
        AM: number;
        Cm: number;
        CM: number;
        Bk: number;
        BK: number;
        Cf: number;
        CF: number;
        Es: number;
        ES: number;
        Fm: number;
        FM: number;
        Md: number;
        MD: number;
        No: number;
        NO: number;
        Lr: number;
        LR: number;
        Rf: number;
        RF: number;
        Db: number;
        DB: number;
        Sg: number;
        SG: number;
        Bh: number;
        BH: number;
        Hs: number;
        HS: number;
        Mt: number;
        MT: number;
    };
    /** rasmol-like element colors */
    rasmol: {
        H: number;
        He: number;
        HE: number;
        Li: number;
        LI: number;
        B: number;
        C: number;
        N: number;
        O: number;
        F: number;
        Na: number;
        NA: number;
        Mg: number;
        MG: number;
        Al: number;
        AL: number;
        Si: number;
        SI: number;
        P: number;
        S: number;
        Cl: number;
        CL: number;
        Ca: number;
        CA: number;
        Ti: number;
        TI: number;
        Cr: number;
        CR: number;
        Mn: number;
        MN: number;
        Fe: number;
        FE: number;
        Ni: number;
        NI: number;
        Cu: number;
        CU: number;
        Zn: number;
        ZN: number;
        Br: number;
        BR: number;
        Ag: number;
        AG: number;
        I: number;
        Ba: number;
        BA: number;
        Au: number;
        AU: number;
    };
    defaultColors: {
        H: number;
        He: number;
        HE: number;
        Li: number;
        LI: number;
        B: number;
        C: number;
        N: number;
        O: number;
        F: number;
        Na: number;
        NA: number;
        Mg: number;
        MG: number;
        Al: number;
        AL: number;
        Si: number;
        SI: number;
        P: number;
        S: number;
        Cl: number;
        CL: number;
        Ca: number;
        CA: number;
        Ti: number;
        TI: number;
        Cr: number;
        CR: number;
        Mn: number;
        MN: number;
        Fe: number;
        FE: number;
        Ni: number;
        NI: number;
        Cu: number;
        CU: number;
        Zn: number;
        ZN: number;
        Br: number;
        BR: number;
        Ag: number;
        AG: number;
        I: number;
        Ba: number;
        BA: number;
        Au: number;
        AU: number;
    };
    greenCarbon: {
        C: number;
        H: number;
        He: number;
        HE: number;
        Li: number;
        LI: number;
        B: number;
        N: number;
        O: number;
        F: number;
        Na: number;
        NA: number;
        Mg: number;
        MG: number;
        Al: number;
        AL: number;
        Si: number;
        SI: number;
        P: number;
        S: number;
        Cl: number;
        CL: number;
        Ca: number;
        CA: number;
        Ti: number;
        TI: number;
        Cr: number;
        CR: number;
        Mn: number;
        MN: number;
        Fe: number;
        FE: number;
        Ni: number;
        NI: number;
        Cu: number;
        CU: number;
        Zn: number;
        ZN: number;
        Br: number;
        BR: number;
        Ag: number;
        AG: number;
        I: number;
        Ba: number;
        BA: number;
        Au: number;
        AU: number;
    };
    cyanCarbon: {
        C: number;
        H: number;
        He: number;
        HE: number;
        Li: number;
        LI: number;
        B: number;
        N: number;
        O: number;
        F: number;
        Na: number;
        NA: number;
        Mg: number;
        MG: number;
        Al: number;
        AL: number;
        Si: number;
        SI: number;
        P: number;
        S: number;
        Cl: number;
        CL: number;
        Ca: number;
        CA: number;
        Ti: number;
        TI: number;
        Cr: number;
        CR: number;
        Mn: number;
        MN: number;
        Fe: number;
        FE: number;
        Ni: number;
        NI: number;
        Cu: number;
        CU: number;
        Zn: number;
        ZN: number;
        Br: number;
        BR: number;
        Ag: number;
        AG: number;
        I: number;
        Ba: number;
        BA: number;
        Au: number;
        AU: number;
    };
    magentaCarbon: {
        C: number;
        H: number;
        He: number;
        HE: number;
        Li: number;
        LI: number;
        B: number;
        N: number;
        O: number;
        F: number;
        Na: number;
        NA: number;
        Mg: number;
        MG: number;
        Al: number;
        AL: number;
        Si: number;
        SI: number;
        P: number;
        S: number;
        Cl: number;
        CL: number;
        Ca: number;
        CA: number;
        Ti: number;
        TI: number;
        Cr: number;
        CR: number;
        Mn: number;
        MN: number;
        Fe: number;
        FE: number;
        Ni: number;
        NI: number;
        Cu: number;
        CU: number;
        Zn: number;
        ZN: number;
        Br: number;
        BR: number;
        Ag: number;
        AG: number;
        I: number;
        Ba: number;
        BA: number;
        Au: number;
        AU: number;
    };
    yellowCarbon: {
        C: number;
        H: number;
        He: number;
        HE: number;
        Li: number;
        LI: number;
        B: number;
        N: number;
        O: number;
        F: number;
        Na: number;
        NA: number;
        Mg: number;
        MG: number;
        Al: number;
        AL: number;
        Si: number;
        SI: number;
        P: number;
        S: number;
        Cl: number;
        CL: number;
        Ca: number;
        CA: number;
        Ti: number;
        TI: number;
        Cr: number;
        CR: number;
        Mn: number;
        MN: number;
        Fe: number;
        FE: number;
        Ni: number;
        NI: number;
        Cu: number;
        CU: number;
        Zn: number;
        ZN: number;
        Br: number;
        BR: number;
        Ag: number;
        AG: number;
        I: number;
        Ba: number;
        BA: number;
        Au: number;
        AU: number;
    };
    whiteCarbon: {
        C: number;
        H: number;
        He: number;
        HE: number;
        Li: number;
        LI: number;
        B: number;
        N: number;
        O: number;
        F: number;
        Na: number;
        NA: number;
        Mg: number;
        MG: number;
        Al: number;
        AL: number;
        Si: number;
        SI: number;
        P: number;
        S: number;
        Cl: number;
        CL: number;
        Ca: number;
        CA: number;
        Ti: number;
        TI: number;
        Cr: number;
        CR: number;
        Mn: number;
        MN: number;
        Fe: number;
        FE: number;
        Ni: number;
        NI: number;
        Cu: number;
        CU: number;
        Zn: number;
        ZN: number;
        Br: number;
        BR: number;
        Ag: number;
        AG: number;
        I: number;
        Ba: number;
        BA: number;
        Au: number;
        AU: number;
    };
    orangeCarbon: {
        C: number;
        H: number;
        He: number;
        HE: number;
        Li: number;
        LI: number;
        B: number;
        N: number;
        O: number;
        F: number;
        Na: number;
        NA: number;
        Mg: number;
        MG: number;
        Al: number;
        AL: number;
        Si: number;
        SI: number;
        P: number;
        S: number;
        Cl: number;
        CL: number;
        Ca: number;
        CA: number;
        Ti: number;
        TI: number;
        Cr: number;
        CR: number;
        Mn: number;
        MN: number;
        Fe: number;
        FE: number;
        Ni: number;
        NI: number;
        Cu: number;
        CU: number;
        Zn: number;
        ZN: number;
        Br: number;
        BR: number;
        Ag: number;
        AG: number;
        I: number;
        Ba: number;
        BA: number;
        Au: number;
        AU: number;
    };
    purpleCarbon: {
        C: number;
        H: number;
        He: number;
        HE: number;
        Li: number;
        LI: number;
        B: number;
        N: number;
        O: number;
        F: number;
        Na: number;
        NA: number;
        Mg: number;
        MG: number;
        Al: number;
        AL: number;
        Si: number;
        SI: number;
        P: number;
        S: number;
        Cl: number;
        CL: number;
        Ca: number;
        CA: number;
        Ti: number;
        TI: number;
        Cr: number;
        CR: number;
        Mn: number;
        MN: number;
        Fe: number;
        FE: number;
        Ni: number;
        NI: number;
        Cu: number;
        CU: number;
        Zn: number;
        ZN: number;
        Br: number;
        BR: number;
        Ag: number;
        AG: number;
        I: number;
        Ba: number;
        BA: number;
        Au: number;
        AU: number;
    };
    blueCarbon: {
        C: number;
        H: number;
        He: number;
        HE: number;
        Li: number;
        LI: number;
        B: number;
        N: number;
        O: number;
        F: number;
        Na: number;
        NA: number;
        Mg: number;
        MG: number;
        Al: number;
        AL: number;
        Si: number;
        SI: number;
        P: number;
        S: number;
        Cl: number;
        CL: number;
        Ca: number;
        CA: number;
        Ti: number;
        TI: number;
        Cr: number;
        CR: number;
        Mn: number;
        MN: number;
        Fe: number;
        FE: number;
        Ni: number;
        NI: number;
        Cu: number;
        CU: number;
        Zn: number;
        ZN: number;
        Br: number;
        BR: number;
        Ag: number;
        AG: number;
        I: number;
        Ba: number;
        BA: number;
        Au: number;
        AU: number;
    };
};
export declare const residues: {
    /** @property standard amino acid color scheme*/
    amino: {
        ALA: number;
        ARG: number;
        ASN: number;
        ASP: number;
        CYS: number;
        GLN: number;
        GLU: number;
        GLY: number;
        HIS: number;
        ILE: number;
        LEU: number;
        LYS: number;
        MET: number;
        PHE: number;
        PRO: number;
        SER: number;
        THR: number;
        TRP: number;
        TYR: number;
        VAL: number;
        ASX: number;
        GLX: number;
    };
    /** @property shapely amino acid color scheme*/
    shapely: {
        ALA: number;
        ARG: number;
        ASN: number;
        ASP: number;
        CYS: number;
        GLN: number;
        GLU: number;
        GLY: number;
        HIS: number;
        ILE: number;
        LEU: number;
        LYS: number;
        MET: number;
        PHE: number;
        PRO: number;
        SER: number;
        THR: number;
        TRP: number;
        TYR: number;
        VAL: number;
        ASX: number;
        GLX: number;
    };
    /** @property nucleic acid color scheme*/
    nucleic: {
        A: number;
        G: number;
        I: number;
        C: number;
        T: number;
        U: number;
    };
};
export declare const chains: {
    /** @property chain based standard color scheme */
    atom: {
        A: number;
        B: number;
        C: number;
        D: number;
        E: number;
        F: number;
        G: number;
        H: number;
        I: number;
        J: number;
        K: number;
        L: number;
        M: number;
        N: number;
        O: number;
        P: number;
        Q: number;
        R: number;
        S: number;
        T: number;
        U: number;
        V: number;
        W: number;
        X: number;
        Y: number;
        Z: number;
    };
    /** @property hetatm color scheme */
    hetatm: {
        A: number;
        B: number;
        C: number;
        D: number;
        E: number;
        F: number;
        G: number;
        H: number;
        I: number;
        J: number;
        K: number;
        L: number;
        M: number;
        N: number;
        O: number;
        P: number;
        Q: number;
        R: number;
        S: number;
        T: number;
        U: number;
        V: number;
        W: number;
        X: number;
        Y: number;
        Z: number;
    };
};
/**
 * built in color schemes
 * The user can pass all of these values directly as the colorscheme and they will use the respective colorscheme
 * @example window.$3Dmol.download("pdb:4UAA",viewer,{},function(){
 *    viewer.setBackgroundColor(0xffffffff);
 *    var colorAsSnake = function(atom) {
 *      return atom.resi % 2 ? 'white': 'green'
 *    };
 *    viewer.setStyle( {chain:'A'}, { cartoon: {colorfunc: colorAsSnake }});
 *    viewer.setStyle( {chain:'B'}, { stick: {colorscheme: 'yellowCarbon'}});
 *    viewer.render();
 *  });
  */
export declare const builtinColorSchemes: {
    ssPyMol: {
        prop: string;
        map: {
            h: number;
            s: number;
            c: number;
        };
    };
    ssJmol: {
        prop: string;
        map: {
            h: number;
            s: number;
            c: number;
        };
    };
    Jmol: {
        prop: string;
        map: {
            H: number;
            He: number;
            HE: number;
            Li: number;
            LI: number;
            Be: number;
            BE: number;
            B: number;
            C: number;
            N: number;
            O: number;
            F: number;
            Ne: number;
            NE: number;
            Na: number;
            NA: number;
            Mg: number;
            MG: number;
            Al: number;
            AL: number;
            Si: number;
            SI: number;
            P: number;
            S: number;
            Cl: number;
            CL: number;
            Ar: number;
            AR: number;
            K: number;
            Ca: number;
            CA: number;
            Sc: number;
            SC: number;
            Ti: number;
            TI: number;
            V: number;
            Cr: number;
            CR: number;
            Mn: number;
            MN: number;
            Fe: number;
            FE: number;
            Co: number;
            CO: number;
            Ni: number;
            NI: number;
            Cu: number;
            CU: number;
            Zn: number;
            ZN: number;
            Ga: number;
            GA: number;
            Ge: number;
            GE: number;
            As: number;
            AS: number;
            Se: number;
            SE: number;
            Br: number;
            BR: number;
            Kr: number;
            KR: number;
            Rb: number;
            RB: number;
            Sr: number;
            SR: number;
            Y: number;
            Zr: number;
            ZR: number;
            Nb: number;
            NB: number;
            Mo: number;
            MO: number;
            Tc: number;
            TC: number;
            Ru: number;
            RU: number;
            Rh: number;
            RH: number;
            Pd: number;
            PD: number;
            Ag: number;
            AG: number;
            Cd: number;
            CD: number;
            In: number;
            IN: number;
            Sn: number;
            SN: number;
            Sb: number;
            SB: number;
            Te: number;
            TE: number;
            I: number;
            Xe: number;
            XE: number;
            Cs: number;
            CS: number;
            Ba: number;
            BA: number;
            La: number;
            LA: number;
            Ce: number;
            CE: number;
            Pr: number;
            PR: number;
            Nd: number;
            ND: number;
            Pm: number;
            PM: number;
            Sm: number;
            SM: number;
            Eu: number;
            EU: number;
            Gd: number;
            GD: number;
            Tb: number;
            TB: number;
            Dy: number;
            DY: number;
            Ho: number;
            HO: number;
            Er: number;
            ER: number;
            Tm: number;
            TM: number;
            Yb: number;
            YB: number;
            Lu: number;
            LU: number;
            Hf: number;
            HF: number;
            Ta: number;
            TA: number;
            W: number;
            Re: number;
            RE: number;
            Os: number;
            OS: number;
            Ir: number;
            IR: number;
            Pt: number;
            PT: number;
            Au: number;
            AU: number;
            Hg: number;
            HG: number;
            Tl: number;
            TL: number;
            Pb: number;
            PB: number;
            Bi: number;
            BI: number;
            Po: number;
            PO: number;
            At: number;
            AT: number;
            Rn: number;
            RN: number;
            Fr: number;
            FR: number;
            Ra: number;
            RA: number;
            Ac: number;
            AC: number;
            Th: number;
            TH: number;
            Pa: number;
            PA: number;
            U: number;
            Np: number;
            NP: number;
            Pu: number;
            PU: number;
            Am: number;
            AM: number;
            Cm: number;
            CM: number;
            Bk: number;
            BK: number;
            Cf: number;
            CF: number;
            Es: number;
            ES: number;
            Fm: number;
            FM: number;
            Md: number;
            MD: number;
            No: number;
            NO: number;
            Lr: number;
            LR: number;
            Rf: number;
            RF: number;
            Db: number;
            DB: number;
            Sg: number;
            SG: number;
            Bh: number;
            BH: number;
            Hs: number;
            HS: number;
            Mt: number;
            MT: number;
        };
    };
    amino: {
        prop: string;
        map: {
            ALA: number;
            ARG: number;
            ASN: number;
            ASP: number;
            CYS: number;
            GLN: number;
            GLU: number;
            GLY: number;
            HIS: number;
            ILE: number;
            LEU: number;
            LYS: number;
            MET: number;
            PHE: number;
            PRO: number;
            SER: number;
            THR: number;
            TRP: number;
            TYR: number;
            VAL: number;
            ASX: number;
            GLX: number;
        };
    };
    shapely: {
        prop: string;
        map: {
            ALA: number;
            ARG: number;
            ASN: number;
            ASP: number;
            CYS: number;
            GLN: number;
            GLU: number;
            GLY: number;
            HIS: number;
            ILE: number;
            LEU: number;
            LYS: number;
            MET: number;
            PHE: number;
            PRO: number;
            SER: number;
            THR: number;
            TRP: number;
            TYR: number;
            VAL: number;
            ASX: number;
            GLX: number;
        };
    };
    nucleic: {
        prop: string;
        map: {
            A: number;
            G: number;
            I: number;
            C: number;
            T: number;
            U: number;
        };
    };
    chain: {
        prop: string;
        map: {
            A: number;
            B: number;
            C: number;
            D: number;
            E: number;
            F: number;
            G: number;
            H: number;
            I: number;
            J: number;
            K: number;
            L: number;
            M: number;
            N: number;
            O: number;
            P: number;
            Q: number;
            R: number;
            S: number;
            T: number;
            U: number;
            V: number;
            W: number;
            X: number;
            Y: number;
            Z: number;
        };
    };
    rasmol: {
        prop: string;
        map: {
            H: number;
            He: number;
            HE: number;
            Li: number;
            LI: number;
            B: number;
            C: number;
            N: number;
            O: number;
            F: number;
            Na: number;
            NA: number;
            Mg: number;
            MG: number;
            Al: number;
            AL: number;
            Si: number;
            SI: number;
            P: number;
            S: number;
            Cl: number;
            CL: number;
            Ca: number;
            CA: number;
            Ti: number;
            TI: number;
            Cr: number;
            CR: number;
            Mn: number;
            MN: number;
            Fe: number;
            FE: number;
            Ni: number;
            NI: number;
            Cu: number;
            CU: number;
            Zn: number;
            ZN: number;
            Br: number;
            BR: number;
            Ag: number;
            AG: number;
            I: number;
            Ba: number;
            BA: number;
            Au: number;
            AU: number;
        };
    };
    default: {
        prop: string;
        map: {
            H: number;
            He: number;
            HE: number;
            Li: number;
            LI: number;
            B: number;
            C: number;
            N: number;
            O: number;
            F: number;
            Na: number;
            NA: number;
            Mg: number;
            MG: number;
            Al: number;
            AL: number;
            Si: number;
            SI: number;
            P: number;
            S: number;
            Cl: number;
            CL: number;
            Ca: number;
            CA: number;
            Ti: number;
            TI: number;
            Cr: number;
            CR: number;
            Mn: number;
            MN: number;
            Fe: number;
            FE: number;
            Ni: number;
            NI: number;
            Cu: number;
            CU: number;
            Zn: number;
            ZN: number;
            Br: number;
            BR: number;
            Ag: number;
            AG: number;
            I: number;
            Ba: number;
            BA: number;
            Au: number;
            AU: number;
        };
    };
    greenCarbon: {
        prop: string;
        map: {
            C: number;
            H: number;
            He: number;
            HE: number;
            Li: number;
            LI: number;
            B: number;
            N: number;
            O: number;
            F: number;
            Na: number;
            NA: number;
            Mg: number;
            MG: number;
            Al: number;
            AL: number;
            Si: number;
            SI: number;
            P: number;
            S: number;
            Cl: number;
            CL: number;
            Ca: number;
            CA: number;
            Ti: number;
            TI: number;
            Cr: number;
            CR: number;
            Mn: number;
            MN: number;
            Fe: number;
            FE: number;
            Ni: number;
            NI: number;
            Cu: number;
            CU: number;
            Zn: number;
            ZN: number;
            Br: number;
            BR: number;
            Ag: number;
            AG: number;
            I: number;
            Ba: number;
            BA: number;
            Au: number;
            AU: number;
        };
    };
    chainHetatm: {
        prop: string;
        map: {
            A: number;
            B: number;
            C: number;
            D: number;
            E: number;
            F: number;
            G: number;
            H: number;
            I: number;
            J: number;
            K: number;
            L: number;
            M: number;
            N: number;
            O: number;
            P: number;
            Q: number;
            R: number;
            S: number;
            T: number;
            U: number;
            V: number;
            W: number;
            X: number;
            Y: number;
            Z: number;
        };
    };
    cyanCarbon: {
        prop: string;
        map: {
            C: number;
            H: number;
            He: number;
            HE: number;
            Li: number;
            LI: number;
            B: number;
            N: number;
            O: number;
            F: number;
            Na: number;
            NA: number;
            Mg: number;
            MG: number;
            Al: number;
            AL: number;
            Si: number;
            SI: number;
            P: number;
            S: number;
            Cl: number;
            CL: number;
            Ca: number;
            CA: number;
            Ti: number;
            TI: number;
            Cr: number;
            CR: number;
            Mn: number;
            MN: number;
            Fe: number;
            FE: number;
            Ni: number;
            NI: number;
            Cu: number;
            CU: number;
            Zn: number;
            ZN: number;
            Br: number;
            BR: number;
            Ag: number;
            AG: number;
            I: number;
            Ba: number;
            BA: number;
            Au: number;
            AU: number;
        };
    };
    magentaCarbon: {
        prop: string;
        map: {
            C: number;
            H: number;
            He: number;
            HE: number;
            Li: number;
            LI: number;
            B: number;
            N: number;
            O: number;
            F: number;
            Na: number;
            NA: number;
            Mg: number;
            MG: number;
            Al: number;
            AL: number;
            Si: number;
            SI: number;
            P: number;
            S: number;
            Cl: number;
            CL: number;
            Ca: number;
            CA: number;
            Ti: number;
            TI: number;
            Cr: number;
            CR: number;
            Mn: number;
            MN: number;
            Fe: number;
            FE: number;
            Ni: number;
            NI: number;
            Cu: number;
            CU: number;
            Zn: number;
            ZN: number;
            Br: number;
            BR: number;
            Ag: number;
            AG: number;
            I: number;
            Ba: number;
            BA: number;
            Au: number;
            AU: number;
        };
    };
    purpleCarbon: {
        prop: string;
        map: {
            C: number;
            H: number;
            He: number;
            HE: number;
            Li: number;
            LI: number;
            B: number;
            N: number;
            O: number;
            F: number;
            Na: number;
            NA: number;
            Mg: number;
            MG: number;
            Al: number;
            AL: number;
            Si: number;
            SI: number;
            P: number;
            S: number;
            Cl: number;
            CL: number;
            Ca: number;
            CA: number;
            Ti: number;
            TI: number;
            Cr: number;
            CR: number;
            Mn: number;
            MN: number;
            Fe: number;
            FE: number;
            Ni: number;
            NI: number;
            Cu: number;
            CU: number;
            Zn: number;
            ZN: number;
            Br: number;
            BR: number;
            Ag: number;
            AG: number;
            I: number;
            Ba: number;
            BA: number;
            Au: number;
            AU: number;
        };
    };
    whiteCarbon: {
        prop: string;
        map: {
            C: number;
            H: number;
            He: number;
            HE: number;
            Li: number;
            LI: number;
            B: number;
            N: number;
            O: number;
            F: number;
            Na: number;
            NA: number;
            Mg: number;
            MG: number;
            Al: number;
            AL: number;
            Si: number;
            SI: number;
            P: number;
            S: number;
            Cl: number;
            CL: number;
            Ca: number;
            CA: number;
            Ti: number;
            TI: number;
            Cr: number;
            CR: number;
            Mn: number;
            MN: number;
            Fe: number;
            FE: number;
            Ni: number;
            NI: number;
            Cu: number;
            CU: number;
            Zn: number;
            ZN: number;
            Br: number;
            BR: number;
            Ag: number;
            AG: number;
            I: number;
            Ba: number;
            BA: number;
            Au: number;
            AU: number;
        };
    };
    orangeCarbon: {
        prop: string;
        map: {
            C: number;
            H: number;
            He: number;
            HE: number;
            Li: number;
            LI: number;
            B: number;
            N: number;
            O: number;
            F: number;
            Na: number;
            NA: number;
            Mg: number;
            MG: number;
            Al: number;
            AL: number;
            Si: number;
            SI: number;
            P: number;
            S: number;
            Cl: number;
            CL: number;
            Ca: number;
            CA: number;
            Ti: number;
            TI: number;
            Cr: number;
            CR: number;
            Mn: number;
            MN: number;
            Fe: number;
            FE: number;
            Ni: number;
            NI: number;
            Cu: number;
            CU: number;
            Zn: number;
            ZN: number;
            Br: number;
            BR: number;
            Ag: number;
            AG: number;
            I: number;
            Ba: number;
            BA: number;
            Au: number;
            AU: number;
        };
    };
    yellowCarbon: {
        prop: string;
        map: {
            C: number;
            H: number;
            He: number;
            HE: number;
            Li: number;
            LI: number;
            B: number;
            N: number;
            O: number;
            F: number;
            Na: number;
            NA: number;
            Mg: number;
            MG: number;
            Al: number;
            AL: number;
            Si: number;
            SI: number;
            P: number;
            S: number;
            Cl: number;
            CL: number;
            Ca: number;
            CA: number;
            Ti: number;
            TI: number;
            Cr: number;
            CR: number;
            Mn: number;
            MN: number;
            Fe: number;
            FE: number;
            Ni: number;
            NI: number;
            Cu: number;
            CU: number;
            Zn: number;
            ZN: number;
            Br: number;
            BR: number;
            Ag: number;
            AG: number;
            I: number;
            Ba: number;
            BA: number;
            Au: number;
            AU: number;
        };
    };
    blueCarbon: {
        prop: string;
        map: {
            C: number;
            H: number;
            He: number;
            HE: number;
            Li: number;
            LI: number;
            B: number;
            N: number;
            O: number;
            F: number;
            Na: number;
            NA: number;
            Mg: number;
            MG: number;
            Al: number;
            AL: number;
            Si: number;
            SI: number;
            P: number;
            S: number;
            Cl: number;
            CL: number;
            Ca: number;
            CA: number;
            Ti: number;
            TI: number;
            Cr: number;
            CR: number;
            Mn: number;
            MN: number;
            Fe: number;
            FE: number;
            Ni: number;
            NI: number;
            Cu: number;
            CU: number;
            Zn: number;
            ZN: number;
            Br: number;
            BR: number;
            Ag: number;
            AG: number;
            I: number;
            Ba: number;
            BA: number;
            Au: number;
            AU: number;
        };
    };
};
/** Return proper color for atom given style
 * @param {AtomSpec} atom
 * @param {AtomStyle} style
 * @return {Color}
 */
export declare function getColorFromStyle(atom: any, style: any): import("./WebGL").Color;
